@@ -83,7 +83,7 @@ class Scenario:
     j = {"store_in_memory": values_dict}
     self._decide(j)
 
-  def read_cells(self, keys_arr, buffer_size=8192):
+  def read_cells(self, keys_arr, buffer_size=0):
     if not self.init or self.nis:
       return None
     j = {"memory_cells": keys_arr}
@@ -93,11 +93,11 @@ class Scenario:
     else:
       return j["memory_values"]
 
-  def listen(self):
+  def listen(self, buffer_size=0):
     if not self.init or self.nis:
       raise ScenarioNotStartedException
     try:
-      j = Scenario._decode_json(self.srv._waits_for())
+      j = Scenario._decode_json(self.srv._waits_for(buffer_size))
     except UnicodeDecodeError:
       print('Unicode decode error.')
       return {}
@@ -106,9 +106,9 @@ class Scenario:
         raise ScenarioTerminatedException
     return j
 
-  def wait(self):
+  def wait(self, buffer_size=0):
     while True:
-      msg = self.listen()
+      msg = self.listen(buffer_size)
       if len(msg) == 0:
         continue
       if msg['author'] == 1:
